<?php
/**
 * ipushs 主題選項
 *
 * @package WordPress
 * @subpackage ipushs
 * @since ipushs 1.0
 */

/**
 * Properly enqueue styles and scripts for our theme options page.
 *
 * This function is attached to the admin_enqueue_scripts action hook.
 *
 * @since ipushs 1.0
 *
 */
function ipushs_admin_enqueue_scripts( $hook_suffix ) {
	wp_enqueue_style( 'ipushs-theme-options', get_template_directory_uri() . '/inc/theme-options.css', false, '2011-04-28' );
	wp_enqueue_script( 'ipushs-theme-options', get_template_directory_uri() . '/inc/theme-options.js', array( 'farbtastic' ), '2011-06-10' );
	wp_enqueue_style( 'farbtastic' );
}
add_action( 'admin_print_styles-appearance_page_theme_options', 'ipushs_admin_enqueue_scripts' );

/**
 * Register the form setting for our ipushs_options array.
 *
 * This function is attached to the admin_init action hook.
 *
 * This call to register_setting() registers a validation callback, ipushs_theme_options_validate(),
 * which is used when the option is saved, to ensure that our option values are complete, properly
 * formatted, and safe.
 *
 * We also use this function to add our theme option if it doesn't already exist.
 *
 * @since ipushs 1.0
 */
function ipushs_theme_options_init() {

	// If we have no options in the database, let's add them now.
	if ( false === ipushs_get_theme_options() )
		add_option( 'ipushs_theme_options', ipushs_get_default_theme_options() );

	register_setting(
		'ipushs_options',       // Options group, see settings_fields() call in ipushs_theme_options_render_page()
		'ipushs_theme_options', // Database option, see ipushs_get_theme_options()
		'ipushs_theme_options_validate' // The sanitization callback, see ipushs_theme_options_validate()
	);

	// Register our settings field group
	add_settings_section(
		'general', // Unique identifier for the settings section
		'', // Section title (we don't want one)
		'__return_false', // Section callback (we don't want anything)
		'theme_options' // Menu slug, used to uniquely identify the page; see ipushs_theme_options_add_page()
	);

	// Register our individual settings fields
	add_settings_field(
		'color_scheme',  // Unique identifier for the field for this section
		__( 'Color Scheme', 'ipushs' ), // Setting field label
		'ipushs_settings_field_color_scheme', // Function that renders the settings field
		'theme_options', // Menu slug, used to uniquely identify the page; see ipushs_theme_options_add_page()
		'general' // Settings section. Same as the first argument in the add_settings_section() above
	);

	add_settings_field( 'link_color', __( 'Link Color',     'ipushs' ), 'ipushs_settings_field_link_color', 'theme_options', 'general' );
	add_settings_field( 'layout',     __( 'Default Layout', 'ipushs' ), 'ipushs_settings_field_layout',     'theme_options', 'general' );
}
add_action( 'admin_init', 'ipushs_theme_options_init' );

/**
 * Change the capability required to save the 'ipushs_options' options group.
 *
 * @see ipushs_theme_options_init() First parameter to register_setting() is the name of the options group.
 * @see ipushs_theme_options_add_page() The edit_theme_options capability is used for viewing the page.
 *
 * By default, the options groups for all registered settings require the manage_options capability.
 * This filter is required to change our theme options page to edit_theme_options instead.
 * By default, only administrators have either of these capabilities, but the desire here is
 * to allow for finer-grained control for roles and users.
 *
 * @param string $capability The capability used for the page, which is manage_options by default.
 * @return string The capability to actually use.
 */
function ipushs_option_page_capability( $capability ) {
	return 'edit_theme_options';
}
add_filter( 'option_page_capability_ipushs_options', 'ipushs_option_page_capability' );

/**
 * Add our theme options page to the admin menu, including some help documentation.
 *
 * This function is attached to the admin_menu action hook.
 *
 * @since ipushs 1.0
 */
function ipushs_theme_options_add_page() {
	$theme_page = add_theme_page(
		__( 'Theme Options', 'ipushs' ),   // Name of page
		__( 'Theme Options', 'ipushs' ),   // Label in menu
		'edit_theme_options',                    // Capability required
		'theme_options',                         // Menu slug, used to uniquely identify the page
		'ipushs_theme_options_render_page' // Function that renders the options page
	);

	if ( ! $theme_page )
		return;

	add_action( "load-$theme_page", 'ipushs_theme_options_help' );
}
add_action( 'admin_menu', 'ipushs_theme_options_add_page' );

function ipushs_theme_options_help() {

	$help = '<p>' . __( 'Some themes provide customization options that are grouped together on a Theme Options screen. If you change themes, options may change or disappear, as they are theme-specific. Your current theme, ipushs, provides the following Theme Options:', 'ipushs' ) . '</p>' .
			'<ol>' .
				'<li>' . __( '<strong>Color Scheme</strong>: You can choose a color palette of "Light" (light background with dark text) or "Dark" (dark background with light text) for your site.', 'ipushs' ) . '</li>' .
				'<li>' . __( '<strong>Link Color</strong>: You can choose the color used for text links on your site. You can enter the HTML color or hex code, or you can choose visually by clicking the "Select a Color" button to pick from a color wheel.', 'ipushs' ) . '</li>' .
				'<li>' . __( '<strong>Default Layout</strong>: You can choose if you want your site&#8217;s default layout to have a sidebar on the left, the right, or not at all.', 'ipushs' ) . '</li>' .
			'</ol>' .
			'<p>' . __( 'Remember to click "Save Changes" to save any changes you have made to the theme options.', 'ipushs' ) . '</p>';

	$sidebar = '<p><strong>' . __( 'For more information:', 'ipushs' ) . '</strong></p>' .
		'<p>' . __( '<a href="http://codex.wordpress.org/Appearance_Theme_Options_Screen" target="_blank">Documentation on Theme Options</a>', 'ipushs' ) . '</p>' .
		'<p>' . __( '<a href="http://wordpress.org/support/" target="_blank">Support Forums</a>', 'ipushs' ) . '</p>';

	$screen = get_current_screen();

	if ( method_exists( $screen, 'add_help_tab' ) ) {
		// WordPress 3.3
		$screen->add_help_tab( array(
			'title' => __( 'Overview', 'ipushs' ),
			'id' => 'theme-options-help',
			'content' => $help,
			)
		);

		$screen->set_help_sidebar( $sidebar );
	} else {
		// WordPress 3.2
		add_contextual_help( $screen, $help . $sidebar );
	}
}

/**
 * Returns an array of color schemes registered for ipushs.
 *
 * @since ipushs 1.0
 */
function ipushs_color_schemes() {
	$color_scheme_options = array(
		'light' => array(
			'value' => 'light',
			'label' => __( 'Light', 'ipushs' ),
			'thumbnail' => get_template_directory_uri() . '/inc/images/light.png',
			'default_link_color' => '#737373'
		),
	);

	return apply_filters( 'ipushs_color_schemes', $color_scheme_options );
}

/**
 * Returns an array of layout options registered for ipushs.
 *
 * @since ipushs 1.0
 */
function ipushs_layouts() {
	$layout_options = array(
		'content' => array(
			'value' => 'content',
			'label' => __( 'One-column, no sidebar', 'ipushs' ),
			'thumbnail' => get_template_directory_uri() . '/inc/images/content.png',
		),
	);

	return apply_filters( 'ipushs_layouts', $layout_options );
}

/**
 * Returns the default options for ipushs.
 *
 * @since ipushs 1.0
 */
function ipushs_get_default_theme_options() {
	$default_theme_options = array(
		'color_scheme' => 'light',
		'link_color'   => ipushs_get_default_link_color( 'light' ),
		'theme_layout' => 'content',
	);


	return apply_filters( 'ipushs_default_theme_options', $default_theme_options );
}

/**
 * Returns the default link color for ipushs, based on color scheme.
 *
 * @since ipushs 1.0
 *
 * @param $string $color_scheme Color scheme. Defaults to the active color scheme.
 * @return $string Color.
*/
function ipushs_get_default_link_color( $color_scheme = null ) {
	if ( null === $color_scheme ) {
		$options = ipushs_get_theme_options();
		$color_scheme = $options['color_scheme'];
	}

	$color_schemes = ipushs_color_schemes();
	if ( ! isset( $color_schemes[ $color_scheme ] ) )
		return false;

	return $color_schemes[ $color_scheme ]['default_link_color'];
}

/**
 * Returns the options array for ipushs.
 *
 * @since ipushs 1.0
 */
function ipushs_get_theme_options() {
	return get_option( 'ipushs_theme_options', ipushs_get_default_theme_options() );
}

/**
 * Renders the Color Scheme setting field.
 *
 * @since ipushs 1.3
 */
function ipushs_settings_field_color_scheme() {
	$options = ipushs_get_theme_options();

	foreach ( ipushs_color_schemes() as $scheme ) {
	?>
	<div class="layout image-radio-option color-scheme">
	<label class="description">
		<input type="radio" name="ipushs_theme_options[color_scheme]" value="<?php echo esc_attr( $scheme['value'] ); ?>" <?php checked( $options['color_scheme'], $scheme['value'] ); ?> />
		<input type="hidden" id="default-color-<?php echo esc_attr( $scheme['value'] ); ?>" value="<?php echo esc_attr( $scheme['default_link_color'] ); ?>" />
		<span>
			<img src="<?php echo esc_url( $scheme['thumbnail'] ); ?>" width="136" height="122" alt="" />
			<?php echo $scheme['label']; ?>
		</span>
	</label>
	</div>
	<?php
	}
}

/**
 * Renders the Link Color setting field.
 *
 * @since ipushs 1.3
 */
function ipushs_settings_field_link_color() {
	$options = ipushs_get_theme_options();
	?>
	<input type="text" name="ipushs_theme_options[link_color]" id="link-color" value="<?php echo esc_attr( $options['link_color'] ); ?>" />
	<a href="#" class="pickcolor hide-if-no-js" id="link-color-example"></a>
	<input type="button" class="pickcolor button hide-if-no-js" value="<?php esc_attr_e( 'Select a Color', 'ipushs' ); ?>" />
	<div id="colorPickerDiv" style="z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;"></div>
	<br />
	<span><?php printf( __( 'Default color: %s', 'ipushs' ), '<span id="default-color">' . ipushs_get_default_link_color( $options['color_scheme'] ) . '</span>' ); ?></span>
	<?php
}

/**
 * Renders the Layout setting field.
 *
 * @since ipushs 1.3
 */
function ipushs_settings_field_layout() {
	$options = ipushs_get_theme_options();
	foreach ( ipushs_layouts() as $layout ) {
		?>
		<div class="layout image-radio-option theme-layout">
		<label class="description">
			<input type="radio" name="ipushs_theme_options[theme_layout]" value="<?php echo esc_attr( $layout['value'] ); ?>" <?php checked( $options['theme_layout'], $layout['value'] ); ?> />
			<span>
				<img src="<?php echo esc_url( $layout['thumbnail'] ); ?>" width="136" height="122" alt="" />
				<?php echo $layout['label']; ?>
			</span>
		</label>
		</div>
		<?php
	}
}

/**
 * Returns the options array for ipushs.
 *
 * @since ipushs 1.2
 */
function ipushs_theme_options_render_page() {
	?>
	<div class="wrap">
		<?php screen_icon(); ?>
		<h2><?php printf( __( '%s Theme Options', 'ipushs' ), get_current_theme() ); ?></h2>
		<?php settings_errors(); ?>

		<form method="post" action="options.php">
			<?php
				settings_fields( 'ipushs_options' );
				do_settings_sections( 'theme_options' );
				submit_button();
			?>
		</form>
	</div>
	<?php
}

/**
 * Sanitize and validate form input. Accepts an array, return a sanitized array.
 *
 * @see ipushs_theme_options_init()
 * @todo set up Reset Options action
 *
 * @since ipushs 1.0
 */
function ipushs_theme_options_validate( $input ) {
	$output = $defaults = ipushs_get_default_theme_options();

	// Color scheme must be in our array of color scheme options
	if ( isset( $input['color_scheme'] ) && array_key_exists( $input['color_scheme'], ipushs_color_schemes() ) )
		$output['color_scheme'] = $input['color_scheme'];

	// Our defaults for the link color may have changed, based on the color scheme.
	$output['link_color'] = $defaults['link_color'] = ipushs_get_default_link_color( $output['color_scheme'] );

	// Link color must be 3 or 6 hexadecimal characters
	if ( isset( $input['link_color'] ) && preg_match( '/^#?([a-f0-9]{3}){1,2}$/i', $input['link_color'] ) )
		$output['link_color'] = '#' . strtolower( ltrim( $input['link_color'], '#' ) );

	// Theme layout must be in our array of theme layout options
	if ( isset( $input['theme_layout'] ) && array_key_exists( $input['theme_layout'], ipushs_layouts() ) )
		$output['theme_layout'] = $input['theme_layout'];

	return apply_filters( 'ipushs_theme_options_validate', $output, $input, $defaults );
}


/**
 * Add a style block to the theme for the current link color.
 *
 * This function is attached to the wp_head action hook.
 *
 * @since ipushs 1.0
 */
function ipushs_print_link_color_style() {
	$options = ipushs_get_theme_options();
	$link_color = $options['link_color'];

	$default_options = ipushs_get_default_theme_options();

	// Don't do anything if the current link color is the default.
	if ( $default_options['link_color'] == $link_color )
		return;
?>
	<style>
		/* Link color */
		a,
		#site-title a:focus,
		#site-title a:hover,
		#site-title a:active,
		.entry-title a:hover,
		.entry-title a:focus,
		.entry-title a:active,
		.widget_ipushs_ephemera .comments-link a:hover,
		section.recent-posts .other-recent-posts a[rel="bookmark"]:hover,
		section.recent-posts .other-recent-posts .comments-link a:hover,
		.format-image footer.entry-meta a:hover,
		#site-generator a:hover {
			color: <?php echo $link_color; ?>;
		}
		section.recent-posts .other-recent-posts .comments-link a:hover {
			border-color: <?php echo $link_color; ?>;
		}
		article.feature-image.small .entry-summary p a:hover,
		.entry-header .comments-link a:hover,
		.entry-header .comments-link a:focus,
		.entry-header .comments-link a:active,
		.feature-slider a.active {
			background-color: <?php echo $link_color; ?>;
		}
	</style>
<?php
}
add_action( 'wp_head', 'ipushs_print_link_color_style' );






/**
 * Adds ipushs layout classes to the array of body classes.
 *
 * @since ipushs 1.0
 */
function ipushs_layout_classes( $existing_classes ) {
	$options = ipushs_get_theme_options();
	$current_layout = $options['theme_layout'];

		$classes[] = $current_layout;

	$classes = apply_filters( 'ipushs_layout_classes', $classes, $current_layout );

	return array_merge( $existing_classes, $classes );
}
add_filter( 'body_class', 'ipushs_layout_classes' );
/**
 * 登記動作
 */
add_action('admin_menu', 'ipushs_page');
/**
 * 版面配置
 */
function ipushs_page (){
 
	if(isset($_POST['ipushs_save']))
	{
		if (is_numeric($_POST['bufferPx'])&&is_numeric($_POST['gutterWidth'])&&is_numeric($_POST['articleWidth']))
		{
			// 更新數據
			$options['gutterWidth'] = $_POST['gutterWidth'];
			$options['articleWidth'] = $_POST['articleWidth'];
			$options['bufferPx'] = $_POST['bufferPx'];
			$options['isAnimated'] = $_POST['isAnimated'];
			$options['isResizable'] = $_POST['isResizable'];
			
			update_option('ipushs_options', $options);
		}
 
	}
	add_theme_page(__('版面配置','ipushs'), __('版面配置','ipushs'), 'edit_themes', basename(__FILE__), 'ipushs_settings');
 
}
 

function ipushs_settings()
{
	$options = get_option('ipushs_options');?>
        
<form method="post" action="">
<div class="wrap">
	<h2><?php _e('Ipushs Theme Options', 'ipushs'); ?></h2>
    <ul>
      <li>
        <label for="gutterWidth" style="width:100px;display:inline-block;"><?php _e('gutterWidth', 'ipushs'); ?>:</label>
        <input name="gutterWidth" id="gutterWidth" type="text" value="<?php if($options['gutterWidth']) echo $options['gutterWidth']; ?>" />
      </li>
      <li>
 		<label for="articleWidth" style="width:100px;display:inline-block;"><?php _e('articleWidth', 'ipushs'); ?>:</label>
        <input name="articleWidth" id="articleWidth" type="text" value="<?php if($options['articleWidth']) echo $options['articleWidth']; ?>" />
      </li>
      <li>
 		<label for="bufferPx" style="width:100px;display:inline-block;"><?php _e('bufferPx', 'ipushs'); ?>:</label>
        <input name="bufferPx" id="bufferPx" type="text" value="<?php if($options['bufferPx']) echo $options['bufferPx']; ?>" />
      </li>
      <li>
 		<label  style="width:100px;display:inline-block;"><?php _e('isAnimated', 'ipushs'); ?>:</label>
        <label for="trueAnimated" ><?php _e('true', 'ipushs'); ?>:</label>
       <input type="radio" name="isAnimated" id="trueAnimated" value="true"  <?php echo $options['isAnimated'] == 'true'?"checked='checked'":'' ?>/>
        <label for="falseAnimated" ><?php _e('false', 'ipushs'); ?>:</label>
       <input type="radio" name="isAnimated" id="falseAnimated" value="false"  <?php echo $options['isAnimated'] == 'false'?"checked='checked'":'' ?>/>
       
      </li>
      <li>
 		<label  style="width:100px;display:inline-block;"><?php _e('isResizable', 'ipushs'); ?>:</label>
        <label for="trueResizable" ><?php _e('true', 'ipushs'); ?>:</label>
       <input type="radio" name="isResizable" id="trueResizable" value="true"  <?php echo $options['isResizable'] == 'true'?"checked='checked'":'' ?>/>
        <label for="falseResizable" ><?php _e('false', 'ipushs'); ?>:</label>
       <input type="radio" name="isResizable" id="falseResizable" value="false"  <?php echo $options['isResizable'] == 'false'?"checked='checked'":'' ?>/>
      </li>
    </ul>
    <p class="submit">
    <input type="submit" name="ipushs_save" class="button-primary" value="<?php _e('Save Changes', 'ipushs'); ?>" />
    </p>
</div>
</form>
<?php	
}